Function build_commit_transaction

pub(crate) fn build_commit_transaction(recipients: &[Address]) -> Transaction
Build the commit part of commit-reveal pair Multiple commits can be in the same tx (if chunks are used, each commit needs a different nonce so that the addresses are different)